@@ -285,7 +285,7 @@ class Anaml:
     def get_generated_features(
         self,
         feature_store: Union[FeatureStoreName, str],
-        primary_key: int
+        primary_key
     ) -> GeneratedFeatures:
         """Get the features generated from a feature store for a particular primary key value.
 
